package com.fs.doctor.service;

import java.util.List;
import com.fs.doctor.domain.DoctorLevelData;

/**
 * 医生级别Service接口
 * 
 * @author fs
 * @date 2026-02-12
 */
public interface IDoctorLevelDataService 
{
    /**
     * 查询医生级别
     * 
     * @param id 医生级别主键
     * @return 医生级别
     */
    public DoctorLevelData selectDoctorLevelDataById(Long id);

    /**
     * 查询医生级别列表
     * 
     * @param doctorLevelData 医生级别
     * @return 医生级别集合
     */
    public List<DoctorLevelData> selectDoctorLevelDataList(DoctorLevelData doctorLevelData);

    /**
     * 新增医生级别
     * 
     * @param doctorLevelData 医生级别
     * @return 结果
     */
    public int insertDoctorLevelData(DoctorLevelData doctorLevelData);

    /**
     * 修改医生级别
     * 
     * @param doctorLevelData 医生级别
     * @return 结果
     */
    public int updateDoctorLevelData(DoctorLevelData doctorLevelData);

    /**
     * 批量删除医生级别
     * 
     * @param ids 需要删除的医生级别主键集合
     * @return 结果
     */
    public int deleteDoctorLevelDataByIds(Long[] ids);

    /**
     * 删除医生级别信息
     * 
     * @param id 医生级别主键
     * @return 结果
     */
    public int deleteDoctorLevelDataById(Long id);
}
